Index: components/webdata/common/web_database_migration_unittest.cc |
diff --git a/components/webdata/common/web_database_migration_unittest.cc b/components/webdata/common/web_database_migration_unittest.cc |
index d93fce510692999725d042a0862a3e7c0abb5010..58cf3a7551e06eeb4aa926a45c0c454472d074b8 100644 |
--- a/components/webdata/common/web_database_migration_unittest.cc |
+++ b/components/webdata/common/web_database_migration_unittest.cc |
@@ -8,6 +8,7 @@ |
#include "base/files/scoped_temp_dir.h" |
#include "base/guid.h" |
#include "base/message_loop.h" |
+#include "base/path_service.h" |
#include "base/stl_util.h" |
#include "base/strings/string16.h" |
#include "base/strings/string_number_conversions.h" |
@@ -19,7 +20,6 @@ |
#include "chrome/browser/webdata/token_service_table.h" |
#include "chrome/browser/webdata/web_apps_table.h" |
#include "chrome/browser/webdata/web_intents_table.h" |
-#include "chrome/test/base/ui_test_utils.h" |
#include "components/autofill/core/browser/autofill_country.h" |
#include "components/autofill/core/browser/autofill_profile.h" |
#include "components/autofill/core/browser/autofill_type.h" |
@@ -207,13 +207,18 @@ class WebDatabaseMigrationTest : public testing::Test { |
} |
// The textual contents of |file| are read from |
// "chrome/test/data/web_database" and returned in the string |contents|. |
// Returns true if the file exists and is read successfully, false otherwise. |
bool GetWebDatabaseData(const base::FilePath& file, std::string* contents) { |
- base::FilePath path = ui_test_utils::GetTestFilePath( |
- base::FilePath(FILE_PATH_LITERAL("web_database")), file); |
- return file_util::PathExists(path) && |
- file_util::ReadFileToString(path, contents); |
+ base::FilePath source_path; |
+ PathService::Get(base::DIR_SOURCE_ROOT, &source_path); |
+ source_path = source_path.AppendASCII("components"); |
+ source_path = source_path.AppendASCII("test"); |
+ source_path = source_path.AppendASCII("data"); |
+ source_path = source_path.AppendASCII("web_database"); |
+ source_path = source_path.Append(file); |
+ return file_util::PathExists(source_path) && |
+ file_util::ReadFileToString(source_path, contents); |
} |
static int VersionFromConnection(sql::Connection* connection) { |
@@ -207,13 +207,18 @@ class WebDatabaseMigrationTest : public testing::Test { |
} |
// The textual contents of |file| are read from |
- // "chrome/test/data/web_database" and returned in the string |contents|. |
+ // "components/test/data/web_database" and returned in the string |contents|. |
// Returns true if the file exists and is read successfully, false otherwise. |
bool GetWebDatabaseData(const base::FilePath& file, std::string* contents) { |